@@ -1,14 +1,9 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
 */
 
 #include "dcc_config.h"
@@ -29,17 +24,22 @@ DCC_Config::DCC_Config(QWidget *parent, const char* name) :
     kcfg_DccPath->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly);
 
     languageChange();
-    connect(kcfg_DccMethodToGetOwnIp, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &DCC_Config::dccMethodChanged);
+    connect(kcfg_DccMethodToGetOwnIp, QOverload<int>::of(&KComboBox::activated), this, &DCC_Config::dccMethodChanged);
     connect(kcfg_DccUPnP, &QCheckBox::stateChanged, this, &DCC_Config::dccUPnPChanged);
     dccMethodChanged(kcfg_DccMethodToGetOwnIp->currentIndex());
     kcfg_DccBufferSize->setSuffix(ki18np(" byte", " bytes"));
     kcfg_DccSendTimeout->setSuffix(ki18np(" second", " seconds"));
 
+// Silence deprecation warnings as long as there is no known substitute for QNetworkConfigurationManager
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     QNetworkConfigurationManager manager;
-    foreach (const QNetworkConfiguration& conf, manager.allConfigurations())
-    {
+    const auto configurations = manager.allConfigurations();
+    for (const QNetworkConfiguration& conf : configurations) {
         kcfg_DccIPv4FallbackIface->addItem(conf.name());
     }
+QT_WARNING_POP
 
 #ifdef Q_OS_WIN
     //This option does nothing under windows, it just confuses the user
@@ -65,11 +65,11 @@ void DCC_Config::dccUPnPChanged(int state)
 {
     DCC::TransferManager *transferManager = Application::instance()->getDccTransferManager();
 
-    if (state == Qt::Checked && transferManager->getUPnPRouter() == NULL)
+    if (state == Qt::Checked && transferManager->getUPnPRouter() == nullptr)
     {
         transferManager->startupUPnP();
     }
-    else if (state == Qt::Unchecked && transferManager->getUPnPRouter() != NULL)
+    else if (state == Qt::Unchecked && transferManager->getUPnPRouter() != nullptr)
     {
         transferManager->shutdownUPnP();
     }
