@@ -1,15 +1,11 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2008 Eike Hein <hein@kde.org>
 */
 
 #include "connectionmanager.h"
+
 #include "connectionsettings.h"
 #include "serversettings.h"
 #include "servergroupsettings.h"
@@ -17,13 +13,13 @@
 #include "application.h"
 #include "mainwindow.h"
 #include "statuspanel.h"
+#include "konversation_log.h"
 
-#include <QRegExp>
-
-#include <QDebug>
 #include <KLocalizedString>
 #include <KMessageBox>
 
+#include <QRegExp>
+
 
 ConnectionManager::ConnectionManager(QObject* parent)
     : QObject(parent), m_overrideAutoReconnect (false)
@@ -88,7 +84,7 @@ void ConnectionManager::connectTo(Konversation::ConnectionFlag flag, int serverG
     {
         settings.setServerGroup(serverGroup);
 
-        if (serverGroup->serverList().size() > 0)
+        if (!serverGroup->serverList().isEmpty())
             settings.setServer(serverGroup->serverList()[0]);
     }
 
@@ -100,16 +96,12 @@ void ConnectionManager::connectTo(Konversation::ConnectionFlag flag, const QList
     QMap<QString,Konversation::ChannelList> serverChannels;
     QMap<QString,ConnectionSettings> serverConnections;
 
-    QList<QUrl>::ConstIterator it = list.constBegin();
-    QList<QUrl>::ConstIterator end = list.constEnd();
-
-    for (; it != end; ++it)
-    {
+    for (const QUrl& url : list) {
         ConnectionSettings settings;
 
-        decodeIrcUrl(it->url(), settings);
+        decodeIrcUrl(url.url(), settings);
 
-        qDebug() << settings.name() << " - "
+        qCDebug(KONVERSATION_LOG) << settings.name() << " - "
                  << settings.server().host() << settings.server().port()
                  << settings.server().password() << " - "
                  << (settings.serverGroup()?settings.serverGroup()->name():QString());
@@ -158,18 +150,18 @@ void ConnectionManager::connectTo(Konversation::ConnectionFlag flag, ConnectionS
 
     connect(server, &Server::destroyed, this, &ConnectionManager::delistConnection);
 
-    connect(server, SIGNAL(connectionStateChanged(Server*,Konversation::ConnectionState)),
-            this, SLOT(handleConnectionStateChange(Server*,Konversation::ConnectionState)));
+    connect(server, &Server::connectionStateChanged,
+            this, &ConnectionManager::handleConnectionStateChange);
 
     connect(server, &Server::awayState, this, &ConnectionManager::connectionChangedAwayState);
 
-    connect(server, SIGNAL(nicksNowOnline(Server*,QStringList,bool)),
-        mainWindow, SLOT(setOnlineList(Server*,QStringList,bool)));
-    connect(server, SIGNAL(awayInsertRememberLine(Server*)),
-        mainWindow, SIGNAL(triggerRememberLines(Server*)));
+    connect(server, &Server::nicksNowOnline,
+        mainWindow, &MainWindow::setOnlineList);
+    connect(server, &Server::awayInsertRememberLine,
+        mainWindow, &MainWindow::triggerRememberLines);
 
-    connect(server, SIGNAL(multiServerCommand(QString,QString)),
-        konvApp, SLOT(sendMultiServerCommand(QString,QString)));
+    connect(server, &Server::multiServerCommand,
+        konvApp, &Application::sendMultiServerCommand);
 }
 
 void ConnectionManager::enlistConnection(int connectionId, Server* server)
@@ -286,18 +278,16 @@ void ConnectionManager::handleReconnect(Server* server)
 
 void ConnectionManager::quitServers()
 {
-    QMap<int, Server*>::ConstIterator it;
-
-    for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-        it.value()->quitServer();
+    for (Server* server : qAsConst(m_connectionList)) {
+        server->quitServer();
+    }
 }
 
 void ConnectionManager::reconnectServers()
 {
-    QMap<int, Server*>::ConstIterator it;
-
-    for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-        it.value()->reconnectServer();
+    for (Server* server : qAsConst(m_connectionList)) {
+        server->reconnectServer();
+    }
 }
 
 void ConnectionManager::decodeIrcUrl(const QString& url, ConnectionSettings& settings)
@@ -313,7 +303,11 @@ void ConnectionManager::decodeIrcUrl(const QString& url, ConnectionSettings& set
     // Parsing address and channel.
     QStringList mangledUrlSegments;
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     mangledUrlSegments = mangledUrl.split(QLatin1Char('/'), QString::KeepEmptyParts);
+#else
+    mangledUrlSegments = mangledUrl.split(QLatin1Char('/'), Qt::KeepEmptyParts);
+#endif
 
     // Check for ",isserver".
     if (mangledUrlSegments[0].contains(QLatin1Char(',')))
@@ -321,9 +315,13 @@ void ConnectionManager::decodeIrcUrl(const QString& url, ConnectionSettings& set
         QStringList addressSegments;
         bool checkIfServerGroup = true;
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         addressSegments = mangledUrlSegments[0].split(QLatin1Char(','), QString::KeepEmptyParts);
+#else
+        addressSegments = mangledUrlSegments[0].split(QLatin1Char(','), Qt::KeepEmptyParts);
+#endif
 
-        if (addressSegments.filter(QStringLiteral("isserver")).size() > 0)
+        if (!addressSegments.filter(QStringLiteral("isserver")).isEmpty())
             checkIfServerGroup = false;
 
         decodeAddress(addressSegments[0], settings, checkIfServerGroup);
@@ -458,7 +456,7 @@ void ConnectionManager::decodeAddress(const QString& address, ConnectionSettings
 
         settings.setServerGroup(serverGroup);
 
-        if (serverGroup->serverList().size() > 0)
+        if (!serverGroup->serverList().isEmpty())
             settings.setServer(serverGroup->serverList()[0]);
     }
     else
@@ -484,21 +482,18 @@ void ConnectionManager::decodeAddress(const QString& address, ConnectionSettings
 
 bool ConnectionManager::reuseExistingConnection(ConnectionSettings& settings, bool interactive)
 {
-    Server* dupe = 0;
+    Server* dupe = nullptr;
     ConnectionDupe dupeType;
     bool doReuse = true;
 
     Application* konvApp = Application::instance();
     MainWindow* mainWindow = konvApp->getMainWindow();
 
-    QMap<int, Server*>::ConstIterator it;
-
-    for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-    {
-        if (it.value()->getServerGroup() && settings.serverGroup()
-            && it.value()->getServerGroup() == settings.serverGroup())
+    for (Server* server : qAsConst(m_connectionList)) {
+        if (server->getServerGroup() && settings.serverGroup()
+            && server->getServerGroup() == settings.serverGroup())
         {
-            dupe = it.value();
+            dupe = server;
             dupeType = SameServerGroup;
 
             break;
@@ -507,11 +502,9 @@ bool ConnectionManager::reuseExistingConnection(ConnectionSettings& settings, bo
 
     if (!dupe)
     {
-        for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-        {
-            if (it.value()->getConnectionSettings().server() == settings.server())
-            {
-                dupe = it.value();
+        for (Server* server : qAsConst(m_connectionList)) {
+            if (server->getConnectionSettings().server() == settings.server()) {
+                dupe = server;
                 dupeType = SameServer;
 
                 break;
@@ -568,14 +561,10 @@ bool ConnectionManager::reuseExistingConnection(ConnectionSettings& settings, bo
         }
         else
         {
-            if (!settings.oneShotChannelList().isEmpty())
-            {
-                Konversation::ChannelList::ConstIterator it = settings.oneShotChannelList().constBegin();
-                Konversation::ChannelList::ConstIterator itend = settings.oneShotChannelList().constEnd();
-
-                for ( ; it != itend; ++it )
-                {
-                    dupe->sendJoinCommand((*it).name(), (*it).password());
+            const auto oneShotChannelList = settings.oneShotChannelList();
+            if (!oneShotChannelList.isEmpty()) {
+                for (const auto& channel : oneShotChannelList) {
+                    dupe->sendJoinCommand(channel.name(), channel.password());
                 }
                 settings.clearOneShotChannelList();
             }
@@ -635,23 +624,23 @@ QList<Server*> ConnectionManager::getServerList() const
 {
     QList<Server*> serverList;
 
-    QMap<int, Server*>::ConstIterator it;
-
-    for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-        serverList.append(it.value());
+    serverList.reserve(m_connectionList.size());
+    for (Server* server : qAsConst(m_connectionList)) {
+        serverList.append(server);
+    }
 
     return serverList;
 }
 
-Server* ConnectionManager::getServerByConnectionId(int connectionId)
+Server* ConnectionManager::getServerByConnectionId(int connectionId) const
 {
     if (m_connectionList.contains(connectionId))
         return m_connectionList[connectionId];
     else
-        return 0;
+        return nullptr;
 }
 
-Server* ConnectionManager::getServerByName(const QString& name, NameMatchFlags flags)
+Server* ConnectionManager::getServerByName(const QString& name, NameMatchFlags flags) const
 {
     if (flags == MatchByIdThenName)
     {
@@ -666,35 +655,31 @@ Server* ConnectionManager::getServerByName(const QString& name, NameMatchFlags f
         }
     }
 
-    QMap<int, Server*>::ConstIterator it;
-
-    for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-    {
-        if (it.value()->getDisplayName() == name || it.value()->getServerName() == name)
-            return it.value();
+    for (Server* server : qAsConst(m_connectionList)) {
+        if (server->getDisplayName() == name || server->getServerName() == name) {
+            return server;
+        }
     }
 
-    return 0;
+    return nullptr;
 }
 
 void ConnectionManager::involuntaryQuitServers()
 {
     m_overrideAutoReconnect = true;
 
-    QMap<int, Server*>::ConstIterator it;
-
-    for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-        it.value()->involuntaryQuit();
+    for (Server* server : qAsConst(m_connectionList)) {
+        server->involuntaryQuit();
+    }
 }
 
 void ConnectionManager::reconnectInvoluntary()
 {
     m_overrideAutoReconnect = false;
 
-    QMap<int, Server*>::ConstIterator it;
-
-    for (it = m_connectionList.constBegin(); it != m_connectionList.constEnd(); ++it)
-        it.value()->reconnectInvoluntary();
+    for (Server* server : qAsConst(m_connectionList)) {
+        server->reconnectInvoluntary();
+    }
 }
 
 void ConnectionManager::onOnlineStateChanged(bool isOnline)
