@@ -1,32 +1,19 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2009-2010 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009-2010 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "whiteboardpaintarea.h"
 
+#include "konversation_log.h"
+
 #include <cmath>
 
 #include <QPainter>
 #include <QPixmap>
 #include <QResizeEvent>
-#include <QPen>
 #include <QStack>
-#include <QDebug>
-
-#if __has_cpp_attribute(clang::fallthrough)
-#define FALLTHROUGH [[clang::fallthrough]];
-#elif __has_cpp_attribute(fallthrough)
-#define FALLTHROUGH [[fallthrough]];
-#else
-#define FALLTHROUGH
-#endif
 
 namespace Konversation
 {
@@ -62,7 +49,7 @@ namespace Konversation
 
         void WhiteBoardPaintArea::setTool(WhiteBoardGlobals::WhiteBoardTool tool)
         {
-            //qDebug() << "newtool" << tool;
+            //qCDebug(KONVERSATION_LOG) << "newtool" << tool;
             if (tool != m_tool && (m_tool == WhiteBoardGlobals::Text || m_tool == WhiteBoardGlobals::TextExtended))
             {
                 finishText();
@@ -257,38 +244,14 @@ namespace Konversation
 
         void WhiteBoardPaintArea::paintEvent(QPaintEvent *event)
         {
-            //qDebug();
+            //qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             QPainter tPaint;
             tPaint.begin(this);
 
-            foreach (const QRect& rect, event->region().rects())
-            {
+            const auto region = event->region();
+            for (const QRect& rect : region) {
                 tPaint.drawPixmap(rect, *m_imagePixmap, rect);
 
-        // Looks cool but doesn't make sense for ColoredLines
-        // Invert overlapping color
-        //        const int tBytePerLine = rect.width() * sizeof(QRgb);
-        //        const int tHeight = rect.height();
-        //        static const int colorMax = 255;
-        //        QImage tOriginal = m_imagePixmap->toImage();
-        //        QImage tOverlay = m_overlayPixmap->toImage();
-        //
-        //        for (int i = rect.y(); i < tHeight; ++i)
-        //        {
-        //            QRgb* tRgb = (QRgb*)tOriginal.scanLine(i);
-        //            QRgb* tOverlayLine = (QRgb*)tOverlay.scanLine(i);
-        //            for (int j = rect.x()*sizeof(QRgb) ; j < tBytePerLine; j += sizeof(QRgb))
-        //            {
-        //                int tAlpha = qAlpha(*tOverlayLine);
-        //                if (tAlpha > 0)
-        //                {
-        //                    *tOverlayLine = qRgb(colorMax^qRed(*tRgb),colorMax^qGreen(*tRgb),colorMax^ qBlue(*tRgb));
-        //                }
-        //                ++tRgb;
-        //                ++tOverlayLine;
-        //            }
-        //        }
-        //        tPaint.drawImage(rect, tOverlay, rect);
                 tPaint.drawPixmap(rect, *m_overlayPixmap, rect);
             }
 
@@ -297,9 +260,9 @@ namespace Konversation
 
         void WhiteBoardPaintArea::resizeEvent(QResizeEvent *event)
         {
-            Q_UNUSED(event);
-            // qDebug() << "newsize:" << event->size();
-            // qDebug() << "newcontent:" << contentsRect().width() << " " << contentsRect().height();
+            Q_UNUSED(event)
+            // qCDebug(KONVERSATION_LOG) << "newsize:" << event->size();
+            // qCDebug(KONVERSATION_LOG) << "newcontent:" << contentsRect().width() << " " << contentsRect().height();
             resizeImage(contentsRect().width(), contentsRect().height());
         }
 
@@ -399,7 +362,7 @@ namespace Konversation
                     return;
 
                 case WhiteBoardGlobals::Selection:
-                    qDebug() << "TODO implement whiteboard Selection";
+                    qCDebug(KONVERSATION_LOG) << "TODO implement whiteboard Selection";
                     return;
                 }
 
@@ -452,7 +415,7 @@ namespace Konversation
                     tPainter.setBrush(m_backgroundColor);
                     // fallthrough, same as WhiteBoardGlobals::Ellipse just
                     // with extra color
-                    FALLTHROUGH
+                    Q_FALLTHROUGH();
                 case WhiteBoardGlobals::Ellipse:
                     {
                         if (isLastPosValid())
@@ -476,7 +439,7 @@ namespace Konversation
                     tPainter.setBrush(m_backgroundColor);
                     // fallthrough, same as WhiteBoardGlobals::Rectangle just
                     // with extra color
-                    FALLTHROUGH
+                    Q_FALLTHROUGH();
                 case WhiteBoardGlobals::Rectangle:
                     {
                         if (isLastPosValid())
@@ -517,7 +480,7 @@ namespace Konversation
                         }
                         else
                         {
-                            qDebug() << "draw eraser point";
+                            qCDebug(KONVERSATION_LOG) << "draw eraser point";
                             tPainter.drawPoint(event->pos());
                             emit usedEraser(m_penWidth, event->pos().x(), event->pos().y(), event->pos().x(), event->pos().y());
                         }
@@ -558,7 +521,7 @@ namespace Konversation
                     break;
                 case WhiteBoardGlobals::Stamp:
                 case WhiteBoardGlobals::Selection:
-                    qDebug() << "TODO implement whiteboard Selection/Stamp";
+                    qCDebug(KONVERSATION_LOG) << "TODO implement whiteboard Selection/Stamp";
                     break;
                 }
                 tPainter.end();
@@ -569,7 +532,7 @@ namespace Konversation
 
         void WhiteBoardPaintArea::keyPressEvent(QKeyEvent* event)
         {
-            // qDebug() << event->text() << event->text().length() << int(event->text()[0].toLatin1());
+            // qCDebug(KONVERSATION_LOG) << event->text() << event->text().length() << int(event->text()[0].toLatin1());
 
             if ((m_tool == WhiteBoardGlobals::Text || m_tool == WhiteBoardGlobals::TextExtended) && isLastPosValid())
             {
@@ -607,7 +570,7 @@ namespace Konversation
             m_lastPos.setY(InvalidLastPos);
         }
 
-        bool WhiteBoardPaintArea::isLastPosValid()
+        bool WhiteBoardPaintArea::isLastPosValid() const
         {
             if (m_lastPos.x() > InvalidLastPos && m_lastPos.y() > InvalidLastPos)
             {
@@ -618,7 +581,7 @@ namespace Konversation
 
         void WhiteBoardPaintArea::checkImageSize(int x1, int y1, int x2, int y2, int penWidth)
         {
-            // qDebug() << x1 << y1 << x2 << y2;
+            // qCDebug(KONVERSATION_LOG) << x1 << y1 << x2 << y2;
             if (width() == WhiteBoardGlobals::MaxImageSize && height() == WhiteBoardGlobals::MaxImageSize)
             {
                 return;
@@ -800,12 +763,12 @@ namespace Konversation
             angle -= M_PI;
             static const qreal radDiff = qreal(2)* M_PI / qreal(360) * 22;
             qreal tRightAngle = angle + radDiff;
-            const int x1Arrow = sin(tRightAngle) * arrowLength + x2;
-            const int y1Arrow = cos(tRightAngle) * arrowLength + y2;
+            const int x1Arrow = static_cast<int>(sin(tRightAngle) * arrowLength + x2);
+            const int y1Arrow = static_cast<int>(cos(tRightAngle) * arrowLength + y2);
 
             qreal tLeftAngle = angle - radDiff;
-            const int x2Arrow = sin(tLeftAngle) * arrowLength + x2;
-            const int y2Arrow = cos(tLeftAngle) * arrowLength + y2;
+            const int x2Arrow = static_cast<int>(sin(tLeftAngle) * arrowLength + x2);
+            const int y2Arrow = static_cast<int>(cos(tLeftAngle) * arrowLength + y2);
 
             painter->drawLine(x1, y1, x2, y2);
             painter->drawLine(x1Arrow, y1Arrow, x2, y2);
@@ -854,8 +817,7 @@ namespace Konversation
                 tPen.setStyle(Qt::CustomDashLine);
 
                 static const qreal dashLength = 4;
-                QVector<qreal> dashes;
-                dashes << dashLength << dashLength;
+                const QVector<qreal> dashes = { dashLength, dashLength };
                 tPen.setDashPattern(dashes);
 
                 tPaint.setPen(tPen);
