@@ -1,16 +1,11 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2005 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2005 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2005 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2005 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2005-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef MAINWINDOW_H
@@ -20,9 +15,9 @@
 #include "preferences.h"
 #include "ssllabel.h"
 
-#include <QStringList>
+#include <KXmlGuiWindow>
 
-#include <kxmlguiwindow.h>
+#include <QStringList>
 
 
 class KToggleAction;
@@ -41,17 +36,19 @@ namespace Konversation
 class MainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
+    friend class ViewContainer;
 
     public:
         MainWindow();
         ~MainWindow() override;
 
-        ViewContainer* getViewContainer() { return m_viewContainer; }
+        ViewContainer* getViewContainer() const { return m_viewContainer; }
         Konversation::TrayIcon* systemTrayIcon() const { return m_trayIcon; }
 
         /** Some errors need to be shown, even when konversation is minimized.
          */
         void focusAndShowErrorMessage(const QString &errorMsg);
+        QSize sizeHint() const override;
 
     Q_SIGNALS:
         void showQuickConnectDialog();
@@ -73,11 +70,19 @@ class MainWindow : public KXmlGuiWindow
         void openServerList();
 
         void openIdentitiesDialog();
-        IdentityPtr editIdentity(IdentityPtr identity);
+        IdentityPtr editIdentity(const IdentityPtr &identity);
 
         void setOnlineList(Server* notifyServer,const QStringList& list, bool changed);
 
-    protected Q_SLOTS:
+    protected:
+        void showEvent(QShowEvent* e) override;
+        void hideEvent(QHideEvent* e) override;
+        void leaveEvent(QEvent* e) override;
+
+        bool queryClose() override;
+        bool event(QEvent* e) override;
+
+    private Q_SLOTS:
         /** This is connected to the preferences settingsChanged signal and acts to compress
         *  multiple successively settingsChanged() signals into a single output
         *  appearanceChanged() signal.
@@ -106,18 +111,10 @@ class MainWindow : public KXmlGuiWindow
 
         void toggleVisibility();
 
-        void showEvent(QShowEvent* e) override;
-        void hideEvent(QHideEvent* e) override;
-        void leaveEvent(QEvent* e) override;
-
-
-    protected:
-        QSize sizeHint() const override;
-
+    private:
         int confirmQuit();
-        bool queryClose() override;
-        bool event(QEvent* e) override;
 
+    private:
         ViewContainer* m_viewContainer;
         Konversation::StatusBar* m_statusBar;
         Konversation::TrayIcon* m_trayIcon;
@@ -130,6 +127,8 @@ class MainWindow : public KXmlGuiWindow
         /** @see settingsChangedSlot() */
         bool m_hasDirtySettings;
         bool m_closeApp;
+
+        Q_DISABLE_COPY(MainWindow)
 };
 
 #endif /* MAINWINDOW_H */
